@@ -2,12 +2,14 @@ package cmdutils
 
 import (
 	"context"
+	"fmt"
 
 	"github.com/kris-nova/logger"
 	"github.com/spf13/cobra"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/eks"
+	"github.com/weaveworks/eksctl/pkg/outposts"
 )
 
 // Cmd holds attributes that are common between commands;
@@ -32,34 +34,9 @@ type Cmd struct {
 // instance of eks.ClusterProvider, it may return an error if configuration
 // is invalid or region is not supported
 func (c *Cmd) NewCtl() (*eks.ClusterProvider, error) {
-	api.SetClusterConfigDefaults(c.ClusterConfig)
-
-	if err := api.ValidateClusterConfig(c.ClusterConfig); err != nil {
-		if c.Validate {
-			return nil, err
-		}
-		logger.Warning("ignoring validation error: %s", err.Error())
+	if err := c.InitializeClusterConfig(); err != nil {
+		return nil, err
 	}
-
-	for i, ng := range c.ClusterConfig.NodeGroups {
-		if err := api.ValidateNodeGroup(i, ng); err != nil {
-			if c.Validate {
-				return nil, err
-			}
-			logger.Warning("ignoring validation error: %s", err.Error())
-		}
-		// defaulting of nodegroup currently depends on validation;
-		// that may change, but at present that's how it's meant to work
-		api.SetNodeGroupDefaults(ng, c.ClusterConfig.Metadata)
-	}
-
-	for i, ng := range c.ClusterConfig.ManagedNodeGroups {
-		api.SetManagedNodeGroupDefaults(ng, c.ClusterConfig.Metadata)
-		if err := api.ValidateManagedNodeGroup(i, ng); err != nil {
-			return nil, err
-		}
-	}
-
 	ctl, err := eks.New(context.TODO(), &c.ProviderConfig, c.ClusterConfig)
 	if err != nil {
 		return nil, err
@@ -72,18 +49,59 @@ func (c *Cmd) NewCtl() (*eks.ClusterProvider, error) {
 	return ctl, nil
 }
 
+// InitializeClusterConfig validates and initializes the ClusterConfig.
+func (c *Cmd) InitializeClusterConfig() error {
+	api.SetClusterConfigDefaults(c.ClusterConfig)
+
+	if err := api.ValidateClusterConfig(c.ClusterConfig); err != nil {
+		if c.Validate {
+			return err
+		}
+		logger.Warning("ignoring validation error: %s", err.Error())
+	}
+
+	for i, ng := range c.ClusterConfig.NodeGroups {
+		if err := api.ValidateNodeGroup(i, ng, c.ClusterConfig); err != nil {
+			if c.Validate {
+				return err
+			}
+			logger.Warning("ignoring validation error: %s", err.Error())
+		}
+		// defaulting of nodegroup currently depends on validation;
+		// that may change, but at present that's how it's meant to work
+		api.SetNodeGroupDefaults(ng, c.ClusterConfig.Metadata, c.ClusterConfig.IsControlPlaneOnOutposts())
+	}
+
+	for i, ng := range c.ClusterConfig.ManagedNodeGroups {
+		api.SetManagedNodeGroupDefaults(ng, c.ClusterConfig.Metadata, c.ClusterConfig.IsControlPlaneOnOutposts())
+		if err := api.ValidateManagedNodeGroup(i, ng); err != nil {
+			return err
+		}
+	}
+	return nil
+}
+
 // NewProviderForExistingCluster is a wrapper for NewCtl that also validates that the cluster exists and is not a
 // registered/connected cluster.
 func (c *Cmd) NewProviderForExistingCluster(ctx context.Context) (*eks.ClusterProvider, error) {
-	provider, err := c.NewCtl()
+	clusterProvider, err := eks.New(ctx, &c.ProviderConfig, c.ClusterConfig)
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("could not create cluster provider from options: %w", err)
 	}
-	if err := provider.RefreshClusterStatus(ctx, c.ClusterConfig); err != nil {
+	if !clusterProvider.IsSupportedRegion() {
+		return nil, ErrUnsupportedRegion(&c.ProviderConfig)
+	}
+	if err := clusterProvider.RefreshClusterStatus(ctx, c.ClusterConfig); err != nil {
 		return nil, err
 	}
 
-	return provider, nil
+	if err := c.InitializeClusterConfig(); err != nil {
+		return nil, err
+	}
+	if c.ClusterConfig.IsControlPlaneOnOutposts() {
+		clusterProvider.AWSProvider = outposts.WrapClusterProvider(clusterProvider.AWSProvider)
+	}
+	return clusterProvider, nil
 }
 
 // AddResourceCmd create a registers a new command under the given verb command
