@@ -5,12 +5,10 @@ import (
 	"strings"
 	"time"
 
-	v4 "github.com/aws/aws-sdk-go-v2/aws/signer/v4"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
-	"github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5/fakes"
 	. "github.com/weaveworks/eksctl/pkg/eks"
 	"github.com/weaveworks/eksctl/pkg/testutils/mockprovider"
 	"github.com/weaveworks/eksctl/pkg/utils/kubeconfig"
@@ -117,16 +115,6 @@ var _ = Describe("eks auth helpers", func() {
 					testAuthenticatorConfig("")
 					testAuthenticatorConfig("arn:aws:iam::111111111111:role/eksctl")
 				})
-
-				It("should create config with embedded token", func() {
-					mockPresigner := ctl.AWSProvider.STSPresigner().(*fakes.FakeSTSPresigner)
-					mockPresigner.PresignGetCallerIdentityReturns(&v4.PresignedHTTPRequest{
-						URL: "https://example.com",
-					}, nil)
-					client, err := kubeProvider.NewClient(cfg)
-					Expect(err).NotTo(HaveOccurred())
-					Expect(client.Config.AuthInfos[client.Config.CurrentContext].Token).To(HavePrefix("k8s-aws-v1."))
-				})
 			})
 		})
 	})
